<?php
/**
 * Common helper functions.
 *
 * @package WEN_Associate
 */

if ( ! function_exists( 'wen_associate_is_social_menu_active' ) ) :

	/**
	 * Check if social menu is active.
	 *
	 * @since 1.0.0
	 * @return bool Bool status for social menu.
	 */
	function wen_associate_is_social_menu_active() {

		$is_menu_set = false;
		// Fetch nav.
		$nav_menu_locations = get_nav_menu_locations();
		if ( isset( $nav_menu_locations['social'] ) && absint( $nav_menu_locations['social'] ) > 0 ) {
			$is_menu_set = true;
		}
		return $is_menu_set;

	}

endif;

if ( ! function_exists( 'wen_associate_simple_breadcrumb' ) ) :

	/**
	 * Simple breadcrumb.
	 *
	 * @since 1.0.0
	 */
	function wen_associate_simple_breadcrumb() {

		$breadcrumb_args = array(
			'container'   => 'div',
			'show_browse' => false,
			'labels'      => array(
				'home' => get_bloginfo( 'name' , 'display' ),
			),
		);
		breadcrumb_trail( $breadcrumb_args );

	}

endif;


if ( ! function_exists( 'wen_associate_apply_theme_shortcode' ) ) :

	/**
	 * Apply theme shortcode.
	 *
	 * @since 1.0.0
	 *
	 * @param string $string Content.
	 * @return string Modified content.
	 */
	function wen_associate_apply_theme_shortcode( $string ) {

		if ( empty( $string ) ) {
			return $string;
		}

		$search = array( '[the_year]', '[site_link]' );

		$replace = array(
			date( 'Y' ),
			'<a href="'. esc_url( home_url( '/' ) ) .'">'. esc_html( get_bloginfo( 'name', 'display' ) ) . '</a>',
		);
		$string = str_replace( $search, $replace, $string );

		return $string;

	}

endif;

if ( ! function_exists( 'wen_associate_get_font_family_from_key' ) ) :

	/**
	 * Return font family from font slug.
	 *
	 * @since 1.0.0
	 *
	 * @param string $key Font slug.
	 * @return string Font name.
	 */
	function wen_associate_get_font_family_from_key( $key ) {

		$output = '';

		$web_fonts = wen_associate_get_web_fonts();
		$os_fonts  = wen_associate_get_os_fonts();

		$fonts = array_merge( $web_fonts, $os_fonts );

		if ( isset( $fonts[ $key ] ) ) {
			$output = $fonts[ $key ]['label'];
		}
		return $output;

	}

endif;


if ( ! function_exists( 'wen_associate_fonts_url' ) ) :

	/**
	 * Return fonts URL.
	 *
	 * @since 1.0.0
	 */
	function wen_associate_fonts_url() {

		$fonts_url = '';
		$fonts     = array();
		$subsets   = 'latin,latin-ext';

		$font_settings = wen_associate_get_font_family_theme_settings_options();
		$web_fonts = wen_associate_get_web_fonts();

		$theme_options = array();
		if ( ! empty( $font_settings ) ) {
			foreach ( $font_settings as $k => $v ) {
				$theme_options[] = wen_associate_get_option( $k );
			}
		}
		$theme_options = array_unique( $theme_options );

		$required_fonts = array();

		if ( ! empty( $theme_options ) ) {
			foreach ( $theme_options as $key => $value ) {
				if ( array_key_exists( $value, $web_fonts ) ) {
					$required_fonts[] = $value;
				}
			}
		}

		if ( ! empty( $required_fonts ) ) {
			foreach ( $required_fonts as $key => $f ) {
				$fonts[] = $web_fonts[ $f ]['name'] . ':400italic,700italic,400,700';
			}
		}

		if ( $fonts ) {
			$fonts_url = add_query_arg( array(
				'family' => urlencode( implode( '|', $fonts ) ),
				'subset' => urlencode( $subsets ),
			), 'https://fonts.googleapis.com/css' );
		}

		$font_load = wen_associate_get_option( 'load_font_cdn' );

		if ( ! $font_load ) {
			require_once get_theme_file_path( 'inc/wptt-webfont-loader.php' );
		
			$fonts_url = wptt_get_webfont_url( $fonts_url );
		}

		return $fonts_url;

	}

endif;

if ( ! function_exists( 'wen_associate_get_sidebar_options' ) ) :

	/**
	 * Get sidebar options.
	 *
	 * @since 1.0.0
	 */
	function wen_associate_get_sidebar_options() {

		global $wp_registered_sidebars;

		$output = array();

		if ( ! empty( $wp_registered_sidebars ) && is_array( $wp_registered_sidebars ) ) {
			foreach ( $wp_registered_sidebars as $key => $sidebar ) {
				$output[ $key ] = $sidebar['name'];
			}
		}

		return $output;

	}

endif;

if ( ! function_exists( 'wen_associate_render_select_dropdown' ) ) :

	/**
	 * Render select dropdown.
	 *
	 * @since 1.0.0
	 *
	 * @param array $main_args Main arguments.
	 * @param string $callback Callback method.
	 * @param array $callback_args Callback arguments.
	 * @return string Rendered markup.
	 */
	function wen_associate_render_select_dropdown( $main_args, $callback, $callback_args = array() ) {

		$defaults = array(
			'id'       => '',
			'name'     => '',
			'selected' => 0,
			'echo'     => 1,
		);

		$r = wp_parse_args( $main_args, $defaults );
		$output = '';
		$choices = array();
		if ( is_callable( $callback ) ) {
			$choices = call_user_func_array( $callback, $callback_args );
		}

		if ( ! empty( $choices ) ) {

		  $output = "<select name='" . esc_attr( $r['name'] ) . "' id='" . esc_attr( $r['id'] ) . "'>\n";
		  foreach ( $choices as $key => $choice ) {
		    $output .= '<option value="' . esc_attr( $key ) . '" ';
		    $output .= selected( $r['selected'], $key, false );
		    $output .= '>' . esc_html( $choice ) . '</option>\n';
		  }
		  $output .= "</select>\n";
		}

		if ( $r['echo'] ) {
		  echo $output;
		}
		return $output;

	}

endif;

if ( ! function_exists( 'wen_associate_the_custom_logo' ) ) :

	/**
	 * Displays custom logo.
	 *
	 * @since 1.1.0
	 */
	function wen_associate_the_custom_logo() {

		if ( function_exists( 'the_custom_logo' ) ) {
			the_custom_logo();
		}

	}

endif;
